lsmeans-package: Least-squares means
Description
This package provides methods for obtaining so-called least-squares means for factor combinations in a variety of fitted linear models. It can also compute contrasts or linear combinations of these least-squares means, (several standard contrast families are provided), and in addition can estimate and contrasts slopes of trend lines.
Popular adjustments for multiple-comparisons are provided. There is also an interface to glht, if the multcomp package is installed, and a compact letter display method for pairwise comparisons.
Examples and discussion are available via vignette("using-lsmeans", package="lsmeans").
Starting with lsmeans version 2, a new object framework based on reference grids is used that increases flexibility and provides for extending its capabilities to additional model objects. Use vignette("lsmeans-changes") for information on the user impact of these changes.
See extending-lsmeans for details on extending to other models.Details
ll{
Package: lsmeans
Type: Package
Version: See DESCRIPTION
Date: See DESCRIPTION
License: GPL-2
}
See the documentation for lsmeans.