lsmeans-package: Least-squares means
Description
This package provides the function lsmeans for outputting so-called least-squares means for factor combinations in an lm, lme, gls, or lmer object. It can also compute contrasts or linear combinations of these least-squares means, and several standard contrast families are provided.
It may also be used for the obtaining linear predictors and contrasts thereof in glm and glmer objects.
Popular adjustments for multiple-comparisons are provided; optionally, contrasts may instead be passed to glht, if the multcomp package is installed.
In analyzing mer objects, if the pbkrtest package is installed, its vcovAdj function is used to bias-adjust the covariance matrix and obtain degrees of freedom.
Examples and discussion are available via vignette("using-lsmeans", package="lsmeans").Details
ll{
Package: lsmeans
Type: Package
Version: See DESCRIPTION
Date: See DESCRIPTION
License: GPL-2
}
See the documentation for lsmeans.