lsmeans-package: Least-squares means
Description
This package provides methods for obtaining so-called least-squares means for factor combinations in a variety of fitted linear models. It can also compute contrasts or linear combinations of these least-squares means, (several standard contrast families are provided), and in addition can estimate and contrasts slopes of trend lines.
Popular adjustments for multiple-comparisons are provided. There is also an interface to glht, if the multcomp package is installed, and a compact letter display method for pairwise comparisons, provided that multcompView is installed.
Examples and discussion are available via vignette("using-lsmeans", package="lsmeans").
Some features of the lsmeans require (or are enhanced by) additional packages that are loaded when needed. Since they are not required packages, they are not automatically installed with lsmeans. We highly recommend that users also install the following packages: multcomp (if cld, glht, or as.glht are to be used), multcompView (for cld), lattice (for lsmip) and pbkrtest (for models fitted by the lme4 package).
Starting with lsmeans version 2, a new object framework based on reference grids is used that increases flexibility and provides for extending its capabilities to additional model objects. Use vignette("lsmeans-changes") for information on the user impact of these changes.
See extending-lsmeans for details on extending to other models.Details
ll{
Package: lsmeans
Type: Package
Version: See DESCRIPTION
Date: See DESCRIPTION
License: GPL-2
Recommended: lattice, multcomp, multcompView, pbkrtest
}
See the documentation for lsmeans.